@@ -1,15 +1,16 @@
 package Hailo::Role::Generic;
 use 5.10.0;
-use Moose::Role;
+use MooseX::Role::Strict;
 use MooseX::Types::Moose qw/HashRef/;
 use namespace::clean -except => 'meta';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 has arguments => (
     isa           => HashRef,
     is            => 'ro',
     documentation => "Arguments passed from Hailo",
+    auto_deref    => 1,
 );
 
 1;
