@@ -1,10 +1,10 @@
 package Hailo::Role::Storage;
 use 5.10.0;
-use Moose::Role;
+use MooseX::Role::Strict;
 use MooseX::Types::Moose qw<Str Int>;
 use namespace::clean -except => 'meta';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 has brain => (
     isa      => Str,
